==> grace-0.4.33.tar.gz: grace-0.4.33/grace/utils.py <==
import os
import sys
import json
import collections


def we_are_frozen():
    # All of the modules are built-in to the interpreter, e.g., by py2exe
    return hasattr(sys, "frozen")


def get_path():
    encoding = sys.getfilesystemencoding()
    if we_are_frozen():
        return os.path.dirname(unicode(sys.executable, encoding))
    return os.path.dirname(unicode(__file__, encoding))


def update(d, u):
    for k, v in u.iteritems():
        if isinstance(v, collections.Mapping):
            r = update(d.get(k, {}), v)
            d[k] = r
        else:
            d[k] = u[k]
    return d


def load_json(string):
    obj = {}

    try:
        obj = json.loads(string)
    except ValueError as e:
        raise e

    return _json_decode(obj)


def write_json(string):
    try:
        return json.dumps(string)
    except:
        raise


def _json_decode_list(data):
    decoded = []

    for item in data:
        if isinstance(item, unicode):
            item = item.encode('utf-8')
        elif isinstance(item, list):
            item = _json_decode_list(item)
        elif isinstance(item, dict):
            item = _json_decode_dict(item)
        decoded.append(item)

    return decoded


def _json_decode_dict(data):
    decoded = {}

    for key, value in data.iteritems():
        if isinstance(key, unicode):
            key = key.encode('utf-8')

        if isinstance(value, unicode):
            value = value.encode('utf-8')
        elif isinstance(value, dict):
            value = _json_decode_dict(value)
        elif isinstance(value, list):
            value = _json_decode_list(value)

        decoded[key] = value

    return decoded


def _json_decode(data):
    if isinstance(data, list):
        return _json_decode_list(data)
    elif isinstance(data, dict):
        return _json_decode_dict(data)
    elif isinstance(data, unicode):
        return data.encode('utf-8')
    else:
        return data

==> grace-0.5.2.tar.gz: grace-0.5.2/grace/utils.py <==
from builtins import str
import os
import sys
import json
import collections
from future.types.newstr import newstr


def we_are_frozen():
    # All of the modules are built-in to the interpreter, e.g., by py2exe
    return hasattr(sys, "frozen")


def get_path():
    encoding = sys.getfilesystemencoding()
    if we_are_frozen():
        return os.path.dirname(sys.executable)
    return os.path.dirname(__file__)


def update(d, u):
    for k, v in u.items():
        if isinstance(v, collections.Mapping):
            r = update(d.get(k, {}), v)
            d[k] = r
        else:
            d[k] = u[k]
    return d


def load_json(string):
    obj = {}

    try:
        obj = json.loads(string)
    except ValueError as e:
        raise e

    if sys.version_info.major < 3:
        return _json_decode(obj)

    # if sys.version_info.major < 3:
    #     d = _json_decode(obj)
    #     if 'dizmo_settings' in d:
    #         print(isinstance(d['dizmo_settings']['display_name'], str))
    #         print(isinstance(d['dizmo_settings']['display_name'], unicode))
    #         print(type(d['dizmo_settings']['display_name']))
    #     return d

    return obj


def write_json(string):
    try:
        return json.dumps(string)
    except:
        raise


def _json_decode_list(data):
    decoded = []

    for item in data:
        if isinstance(item, unicode):
            item = str(item)
        elif isinstance(item, list):
            item = _json_decode_list(item)
        elif isinstance(item, dict):
            item = _json_decode_dict(item)
        decoded.append(item)

    return decoded


def _json_decode_dict(data):
    decoded = {}

    for key, value in data.items():
        if isinstance(key, unicode):
            key = str(key)

        if isinstance(value, unicode):
            value = str(value)
        elif isinstance(value, dict):
            value = _json_decode_dict(value)
        elif isinstance(value, list):
            value = _json_decode_list(value)

        decoded[key] = value

    return decoded


def _json_decode(data):
    if isinstance(data, list):
        return _json_decode_list(data)
    elif isinstance(data, dict):
        return _json_decode_dict(data)
    elif isinstance(data, unicode):
        return str(data)
    else:
        return data


def isstring(string):
    if isinstance(string, str):
        return True

    if sys.version_info.major < 3:
        if isinstance(string, newstr):
            return True
        if isinstance(string, basestring):
            return True

    return False
